@@ -73,7 +73,7 @@ _nlu_personal = {
 
     # Emoras meals
     '{'
-    '[what,you,eat],'
+    '[{can,do,what,how},you,eat],'
     '[{you,your},favorite,#LEM(snack)],'
     '<{you,your},#EXP(like),#LEM(snack)>'
     '}':{
