@@ -10,11 +10,13 @@ from emora._flows.sibling import sibling
 from emora._flows.relationships import relationships
 from emora._flows.coronavirus import coronavirus
 from emora._flows.animals import animals
+from emora._flows.vacations import df as vacations
 
 from _globals import PATHDIR
 from emora_stdm import CompositeDialogueFlow,DialogueFlow
 import emora_stdm
 from emora._flows._global_nlu import personal_nlu, global_update_rules
+from emora._flows._macros import macros
 
 flow_components = {
     'school_new': school2,
@@ -27,31 +29,54 @@ flow_components = {
     'sibling': sibling,
     'relationships': relationships,
     'cvopen': coronavirus,
-    'animals': animals
+    'animals': animals,
+    'vacations': vacations
 }
 
 cdf = CompositeDialogueFlow('root', 'recovery_from_failure', 'recovery_from_failure', DialogueFlow.Speaker.USER)
 cdf.add_state('root', 'root')
-cdf.add_user_transition('root', 'root', '/.*/ #RAND(life_in,True)')
+cdf.add_user_transition('root', 'root', '/.*/')
 cdf.component('SYSTEM').knowledge_base().load_json_file(PATHDIR.replace('__***__','_common.json'))
 
 for namespace, component in flow_components.items():
     cdf.add_component(component, namespace)
 
 cdf.add_system_transition('root', 'house:start', '')
+
 cdf.add_system_transition('root', 'worklife:start', '')
-cdf.add_system_transition('root', 'school_new:start', '')
+cdf.add_system_transition('root', 'worklife:start->worklife:remember_is_employed_open', '', score=9.0)
+cdf.add_system_transition('root', 'worklife:start->worklife:like_job_answer', '', score=10.0)
+
+cdf.add_system_transition('root', 'school_new:start', '', score=2.0)
 cdf.add_system_transition('root', 'sibling:start', '')
+
 cdf.add_system_transition('root', 'relationships:dating', '')
+cdf.add_system_transition('root', 'relationships:dating->relationships:relationship_length', '', score=10.0)
 cdf.add_system_transition('root', 'relationships:marriage', '')
+cdf.add_system_transition('root', 'relationships:marriage->relationships:how_long_married', '', score=10.0)
+
 cdf.add_system_transition('root', 'baby:start', '')
-cdf.add_system_transition('root', 'cvopen:start', '',score=0.0)
+cdf.add_system_transition('root', 'baby:start->baby:asked_kids_age', '', score=10.0)
+
+cdf.add_system_transition('root', 'cvopen:start', '',score=2.0)
+
 
 for component in cdf.components():
-    component.load_global_nlu(personal_nlu, 5.0)
     component.load_update_rules(global_update_rules)
+    component.load_global_nlu(personal_nlu, 5.0)
     component.add_macros({'CNC': emora_stdm.CheckNotComponent(cdf)})
+    component.add_macros(macros)
 
 if __name__ == '__main__':
     #cdf.precache_transitions()
-    cdf.run(debugging=True)
\ No newline at end of file
+    #cdf.run(debugging=False)
+    deb = True
+    while True:
+        cdf.controller().set_speaker(DialogueFlow.Speaker.USER)
+        cdf.user_turn(input('U: '),debugging=deb)
+        cdf.controller().set_speaker(DialogueFlow.Speaker.SYSTEM)
+        vars = cdf.controller().vars()
+        # for k, v in vars.items():
+        #     if '_' != k[0]:
+        #         print('{:<15} {}'.format(k + ':', v))
+        print('E:', cdf.system_turn(debugging=deb))
