@@ -133,7 +133,7 @@ system = {
 
                     '`Well, that\'s interesting. I don\'t seem to know that kind of '
                     'animal. It must be pretty special. `'
-                    '#SET($pet_type=pet)':
+                    '#SET($pet_type=pet,$pet_subj=your pet,$pet_obj=your pet)':
                         'ask_favorite_thing'
                 }
             }
