@@ -4,13 +4,12 @@ from emora_stdm import DialogueFlow
 
 house = DialogueFlow('_local_start')
 house.knowledge_base().load_json_file(PATHDIR.replace('__***__','_common.json'))
-house.add_system_transition('_local_start', 'start', '#RAND(life_in,True)')
+house.add_system_transition('_local_start', 'start', '')
 
 
 system = {
     'state': 'start',
-    'enter': '#GATE #GCOM(house) #GOAL(house) #IF($life_in=True,$life_started=True) '
-             '#ANY($relationship_status=married,$relationship_status=divorced,$partner=husband,$partner=wife)',
+    'enter': '#GATE #GCOM(house) #GOAL(house) #IF($is_adult=True)',
 
     '`Do you want to know something? I can\'t stop thinking about my day yesterday. '
     'My friends came over to my new apartment for the first time and it was so much fun.`'
@@ -110,6 +109,9 @@ system = {
             'state': 'user_living'
         }
     }
+
+
+
 }
 
 user_living = {
@@ -559,7 +561,7 @@ live_with = {
         },
 
         '[{#DISAGREE, alone, myself, no one, nobody, anybody, me too, neither, either, i do not, have not}]'
-        '#SET($user_lives_alone=True)':{
+        '#SET($lives_alone=True)':{
             'score': 0.9,
             'state': 'lives_alone',
 
