@@ -9,7 +9,9 @@ relationships.add_system_transition('_local_start', 'start', '')
 
 system = {
     'state': 'dating',
-    'enter': '#GATE #GCOM(relationship) #GOAL(relationship) #IF($life_in=True,$life_started=True) #ANY($in_high_school=True,$in_college=True)',
+    'enter': '#GATE #GCOM(relationship) #GOAL(relationship)'
+             '#ALL($is_child=False,$relationship_status!=married,$relationship_status!=engaged,$entered_dating!=True)'
+             '#SET($entered_dating=True)',
 
     '#DEFAULT': {
         'state': 'default_relationship',
@@ -18,6 +20,12 @@ system = {
         '`Wait, are you currently dating anyone?`': 'ask_relationship'
     },
 
+    '`You seem really happy with your ` $partner `. How long have you guys been together?`'
+    '#IN($partner, #U(boyfriend, girlfriend, partner))': {
+        'state': 'relationship_length',
+        'score': 2.0
+    },
+
     '`I hope you don\'t mind me asking, but are you dating anyone right now?`'
     '#GSRET(default_relationship)':{
         'state': 'ask_relationship',
@@ -236,8 +244,7 @@ system = {
 
             '`Hmm. Interesting. Anyway, `': 'exit'
         }
-    }
-
+    },
 }
 
 friend_married = {
@@ -248,7 +255,10 @@ friend_married = {
 
 marriage = {
     'state': 'marriage',
-    'enter': '#GATE #GCOM(relationship) #GOAL(relationship) #IF($life_in=True,$life_started=True) #ANY($is_student=False,$is_student=None)',
+    'enter': '#GATE #GCOM(relationship) #GOAL(relationship) '
+             '#IF($is_child!=True, $relationship_status!=single, $relationship_status!=dating, '
+                '$relationship_status!=divorced, $entered_marriage!=True)'
+             '#SET($entered_marriage=True)',
 
     '#DEFAULT': {
         'state': 'default_marriage',
@@ -257,6 +267,13 @@ marriage = {
         '`Wait, so, are you married?`': 'ask_relationship'
     },
 
+    '`So you mentioned you were married. How long have you and your ` $partner ` been together?`'
+    '#IF($relationship_status=married) #GSRET(friend_married_default)':
+    {
+        'state': 'how_long_married',
+        'score': 2.0
+    },
+
     '`I hope you don\'t mind me asking, but are you married?`'
     '#GSRET(default_marriage)': {
         'state': 'asked_married',
@@ -370,7 +387,7 @@ marriage = {
             'state': 'married_n',
 
             '`That\'s alright. It is hard to find the right person. Are you currently seeing anyone?`'
-            '#GSRET(default_relationship)':
+            '#GSRET(default_relationship) #IF($entered_dating!=True) #SET($entered_dating=True)':
                 'ask_relationship'
         },
 
@@ -378,7 +395,7 @@ marriage = {
             'state': 'ask_relationship',
             'hop': 'True'
         }
-    }
+    },
 }
 
 wedding_talk = {
