@@ -9,7 +9,7 @@ school.add_system_transition('_local_start', 'start', '')
 
 system = {
     'state': 'start',
-    'enter': '#GATE #GCOM(school) #GOAL(school) #IF($life_in=True) #SET($life_started=True)',
+    'enter': '#GATE #GCOM(school) #GOAL(school)',
 
     '#DEFAULT':{
         'state': 'default_start',
@@ -31,7 +31,7 @@ system = {
         '}'
         ']'
         '}'
-        '#SET($is_student=True)':{
+        '#SET($is_student=True,$is_child=True)':{
             'state': 'user_is_student',
 
             '#DEFAULT `So, do you like being a student?`': 'ask_user_like_school',
@@ -197,7 +197,7 @@ system = {
         },
 
         '[{#DISAGREE,[i am not]}]'
-        '#SET($is_student=False)': {
+        '#SET($is_student=False,$is_child=False)': {
             'state': 'user_not_student',
 
             '`Oh, really? I am a student myself right now, and I have no idea what I want to do afterwards. `'
@@ -206,7 +206,7 @@ system = {
         },
 
         '[!-{like,dislike,hate,love,enjoy} [i,not, {a student,in school,[#LEM(take) class]}]]'
-        '#SET($is_student=False)': {
+        '#SET($is_student=False,$is_child=False)': {
             'score': 1.1,
             'state': 'user_not_student'
         },
@@ -235,7 +235,8 @@ system = {
             'score': 1.1
         },
 
-        '[#NOT(not),{am,just},{graduated,graduating}]':{
+        '[#NOT(not),{graduated,graduating}]'
+        '#SET($is_student=False,$is_child=False)':{
             'state': 'graduating',
             'score': 1.1,
 
