@@ -9,7 +9,7 @@ sibling.add_system_transition('_local_start', 'start', '')
 
 siblings = {
     'state': 'start',
-    'enter': '#GATE #GCOM(sibling) #GOAL(sibling) #IF($life_in=True,$life_started=True)',
+    'enter': '#GATE #GCOM(sibling) #GOAL(sibling)',
 
     '#IF($sibling=None)': 'ask_sibling',
 
