@@ -9,9 +9,27 @@ work.add_system_transition('_local_start', 'start', '')
 
 system = {
     'state': 'start',
-    'enter': '#GATE #GCOM(work) #GOAL(work) #IF($life_in=True,$life_started=True) #ANY($is_student=False,$is_student=None)',
+    'enter': '#GATE #GCOM(work) #GOAL(work) #ALL($is_child=False,$entered_work!=True) #SET($entered_work=True)',
 
-    '#IF($is_employed=False) #SCORE(1.1) `So, I remember you said you don\'t have a job. `': 'younger_job_wish',
+    '`So, I remember you said you don\'t have a job. `'
+    '#IF($is_employed=False)':{
+        'state': 'younger_job_wish',
+        'score': 2.0
+    },
+
+    '`So you said you have a job, right? What do you do?`'
+    '#IF($is_employed=True) #GSRET(default_start)': {
+        'state': 'remember_is_employed_open',
+        'score': 2.0,
+        'hop': True,
+
+        '': 'asked_job'
+    },
+
+    '`So you said you\'re a ` $job `, right? Do you like your job?`': {
+        'state': 'like_job_answer',
+        'score': 2.0,
+    },
 
     '#DEFAULT':{
         'state': 'default_start',
@@ -158,13 +176,17 @@ job_wishes = {
 
             '`This is a fun question. When you were younger, what did you want to be when you grew up?`'
             '#GSRET(emoras_job_wish)': {
+                'state': 'job_wish_q',
 
                 '{[$younger_job_wish=#ONT(_job)], [a, #POS(noun)]}': {
+                    'state': 'job_wish_r',
 
                     '`I think that\'s a good dream! What changed?`'
                     '#GSRET(emoras_job_wish)': {
+                        'state': 'ack_job_wishe',
 
                         '#UNX': {
+                            'state': 'job_wish_unx',
 
                             '`It seems like everything changes when you get older.`': 'emoras_job_wish'
                         }
@@ -173,12 +195,15 @@ job_wishes = {
                     '#EQ($younger_job_wish,$job) '
                     '`It sounds like you always knew what you wanted to do! That\'s pretty cool that it worked out for you.`'
                     '#GSRET(emoras_job_wish)':{
+                        'state': 'same_job_as_wishes',
+                        'score': 1.1,
 
                         '#UNX': 'emoras_job_wish'
                     }
                 },
 
                 '#IDK': {
+                    'state': 'job_wish_idk',
 
                     '`Fair enough. You know, `': 'emoras_job_wish'
                 },
