@@ -5,7 +5,6 @@ from emora_stdm import DialogueFlow
 
 world = DialogueFlow('_local_start')
 world.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
-world.knowledge_base().load_json_file(PATHDIR.replace('__***__', 'world.json'))
 world.add_system_transition('_local_start', 'start', '')
 
 system = {
@@ -25,9 +24,10 @@ user_does_not_believe_emora = {
         'error':{
             'state': 'explanation',
 
-            '`I think most people assume I can just talk and listen to people, but I actually live in a '
+            '` I think most people assume I can just talk and listen to people, but I actually live in a '
             'virtual world where I have friends and I can do things like play basketball.`'
-            '#GATE #GSRET(exit)':{
+            '#GATE #GSRET(exit)': {
+                'score': 1.1,
 
                 '#INTERESTED':{
 
@@ -46,7 +46,10 @@ user_does_not_believe_emora = {
                 },
 
                 '#UNX': 'exit'
-            }
+            },
+
+            '` It\'s hard to have a conversation with someone if they think the worst of you, so I hope this '
+            'isn\'t the case here. Anyways, `': 'exit'
         },
 
         '[!-#NEGATION [i, {believe, do}]]':{
